summaryrefslogtreecommitdiffstats
path: root/chrome
diff options
context:
space:
mode:
authoravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-15 19:38:48 +0000
committeravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-15 19:38:48 +0000
commitd8e74e81a8df95ef4d63c33e2567e4f6c761a32d (patch)
treeee9a1e813b6f05f84719984ba28b9a25ac325783 /chrome
parentce6fded2cc25479c5991f33a8087237579dff64d (diff)
downloadchromium_src-d8e74e81a8df95ef4d63c33e2567e4f6c761a32d.zip
chromium_src-d8e74e81a8df95ef4d63c33e2567e4f6c761a32d.tar.gz
chromium_src-d8e74e81a8df95ef4d63c33e2567e4f6c761a32d.tar.bz2
fav icon -> favicon. Pass 8: content/
BUG=76073 TEST=none; no visible change Review URL: http://codereview.chromium.org/6677051 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@78256 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome')
-rw-r--r--chrome/browser/favicon_helper.cc8
-rw-r--r--chrome/browser/prerender/prerender_contents.cc2
-rw-r--r--chrome/browser/ui/cocoa/tabs/tab_strip_controller.mm2
-rw-r--r--chrome/browser/ui/gtk/tabs/tab_renderer_gtk.cc2
-rw-r--r--chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc2
-rw-r--r--chrome/common/render_messages.h8
-rw-r--r--chrome/renderer/render_view.cc14
-rw-r--r--chrome/renderer/render_view.h2
8 files changed, 20 insertions, 20 deletions
diff --git a/chrome/browser/favicon_helper.cc b/chrome/browser/favicon_helper.cc
index 68918ab..43dc691 100644
--- a/chrome/browser/favicon_helper.cc
+++ b/chrome/browser/favicon_helper.cc
@@ -142,8 +142,8 @@ void FaviconHelper::OnUpdateFaviconURL(int32 page_id, const GURL& icon_url) {
bool FaviconHelper::OnMessageReceived(const IPC::Message& message) {
bool handled = true;
IPC_BEGIN_MESSAGE_MAP(FaviconHelper, message)
- IPC_MESSAGE_HANDLER(ViewHostMsg_UpdateFavIconURL, OnUpdateFaviconURL)
- IPC_MESSAGE_HANDLER(ViewHostMsg_DidDownloadFavIcon, OnDidDownloadFavicon)
+ IPC_MESSAGE_HANDLER(ViewHostMsg_UpdateFaviconURL, OnUpdateFaviconURL)
+ IPC_MESSAGE_HANDLER(ViewHostMsg_DidDownloadFavicon, OnDidDownloadFavicon)
IPC_MESSAGE_UNHANDLED(handled = false)
IPC_END_MESSAGE_MAP()
return handled;
@@ -263,7 +263,7 @@ void FaviconHelper::OnFaviconData(
return;
// No need to update the favicon url. By the time we get here
- // UpdateFavIconURL will have set the favicon url.
+ // UpdateFaviconURL will have set the favicon url.
if (know_favicon && data.get() && data->size()) {
// There is a favicon, set it now. If expired we'll download the current
@@ -282,7 +282,7 @@ int FaviconHelper::ScheduleDownload(const GURL& url,
const GURL& image_url,
int image_size,
ImageDownloadCallback* callback) {
- const int download_id = tab_contents()->render_view_host()->DownloadFavIcon(
+ const int download_id = tab_contents()->render_view_host()->DownloadFavicon(
image_url, image_size);
if (download_id) {
diff --git a/chrome/browser/prerender/prerender_contents.cc b/chrome/browser/prerender/prerender_contents.cc
index 4323dff..ce09e17 100644
--- a/chrome/browser/prerender/prerender_contents.cc
+++ b/chrome/browser/prerender/prerender_contents.cc
@@ -377,7 +377,7 @@ bool PrerenderContents::OnMessageReceived(const IPC::Message& message) {
OnDidStartProvisionalLoadForFrame)
IPC_MESSAGE_HANDLER(ViewHostMsg_DidRedirectProvisionalLoad,
OnDidRedirectProvisionalLoad)
- IPC_MESSAGE_HANDLER(ViewHostMsg_UpdateFavIconURL, OnUpdateFaviconURL)
+ IPC_MESSAGE_HANDLER(ViewHostMsg_UpdateFaviconURL, OnUpdateFaviconURL)
IPC_MESSAGE_UNHANDLED(handled = false)
IPC_END_MESSAGE_MAP_EX()
diff --git a/chrome/browser/ui/cocoa/tabs/tab_strip_controller.mm b/chrome/browser/ui/cocoa/tabs/tab_strip_controller.mm
index d23fa87..5b47e31 100644
--- a/chrome/browser/ui/cocoa/tabs/tab_strip_controller.mm
+++ b/chrome/browser/ui/cocoa/tabs/tab_strip_controller.mm
@@ -1260,7 +1260,7 @@ private:
TabController* tabController = [tabArray_ objectAtIndex:index];
bool oldHasIcon = [tabController iconView] != nil;
- bool newHasIcon = contents->ShouldDisplayFavIcon() ||
+ bool newHasIcon = contents->ShouldDisplayFavicon() ||
tabStripModel_->IsMiniTab(modelIndex); // Always show icon if mini.
TabLoadingState oldState = [tabController loadingState];
diff --git a/chrome/browser/ui/gtk/tabs/tab_renderer_gtk.cc b/chrome/browser/ui/gtk/tabs/tab_renderer_gtk.cc
index af4b80f..114d07c 100644
--- a/chrome/browser/ui/gtk/tabs/tab_renderer_gtk.cc
+++ b/chrome/browser/ui/gtk/tabs/tab_renderer_gtk.cc
@@ -313,7 +313,7 @@ void TabRendererGtk::UpdateData(TabContents* contents,
// Loading state also involves whether we show the favicon, since that's where
// we display the throbber.
data_.loading = contents->is_loading();
- data_.show_icon = contents->ShouldDisplayFavIcon();
+ data_.show_icon = contents->ShouldDisplayFavicon();
}
void TabRendererGtk::UpdateFromModel() {
diff --git a/chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc b/chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc
index 9ab32bd..988b582 100644
--- a/chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc
+++ b/chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc
@@ -397,7 +397,7 @@ void BrowserTabStripController::SetTabRendererDataFromModel(
data->loading = contents->is_loading();
data->crashed_status = contents->crashed_status();
data->incognito = contents->profile()->IsOffTheRecord();
- data->show_icon = contents->ShouldDisplayFavIcon();
+ data->show_icon = contents->ShouldDisplayFavicon();
data->mini = model_->IsMiniTab(model_index);
data->blocked = model_->IsTabBlocked(model_index);
data->app = contents->is_app();
diff --git a/chrome/renderer/render_view.cc b/chrome/renderer/render_view.cc
index 84a8be7..ab3d79a 100644
--- a/chrome/renderer/render_view.cc
+++ b/chrome/renderer/render_view.cc
@@ -1038,7 +1038,7 @@ bool RenderView::OnMessageReceived(const IPC::Message& message) {
IPC_MESSAGE_HANDLER(ViewMsg_ResetPageEncodingToDefault,
OnResetPageEncodingToDefault)
IPC_MESSAGE_HANDLER(ViewMsg_SetupDevToolsClient, OnSetupDevToolsClient)
- IPC_MESSAGE_HANDLER(ViewMsg_DownloadFavIcon, OnDownloadFavIcon)
+ IPC_MESSAGE_HANDLER(ViewMsg_DownloadFavicon, OnDownloadFavicon)
IPC_MESSAGE_HANDLER(ViewMsg_ScriptEvalRequest, OnScriptEvalRequest)
IPC_MESSAGE_HANDLER(ViewMsg_CSSInsertRequest, OnCSSInsertRequest)
IPC_MESSAGE_HANDLER(ViewMsg_AddMessageToConsole, OnAddMessageToConsole)
@@ -2185,7 +2185,7 @@ void RenderView::didStopLoading() {
// The feed discovery code would also benefit from access to the head.
GURL favicon_url(webview()->mainFrame()->favIconURL());
if (!favicon_url.is_empty())
- Send(new ViewHostMsg_UpdateFavIconURL(routing_id_, page_id_, favicon_url));
+ Send(new ViewHostMsg_UpdateFaviconURL(routing_id_, page_id_, favicon_url));
AddGURLSearchProvider(webview()->mainFrame()->openSearchDescriptionURL(),
ViewHostMsg_PageHasOSDD_Type::Autodetected());
@@ -3494,7 +3494,7 @@ void RenderView::didReceiveTitle(WebFrame* frame, const WebString& title) {
void RenderView::didChangeIcons(WebFrame* frame) {
if (!frame->parent()) {
- Send(new ViewHostMsg_UpdateFavIconURL(
+ Send(new ViewHostMsg_UpdateFaviconURL(
routing_id_,
page_id_,
frame->favIconURL()));
@@ -3999,7 +3999,7 @@ bool RenderView::DownloadImage(int id, const GURL& image_url, int image_size) {
void RenderView::DidDownloadImage(ImageResourceFetcher* fetcher,
const SkBitmap& image) {
// Notify requester of image download status.
- Send(new ViewHostMsg_DidDownloadFavIcon(routing_id_,
+ Send(new ViewHostMsg_DidDownloadFavicon(routing_id_,
fetcher->id(),
fetcher->image_url(),
image.isNull(),
@@ -4018,7 +4018,7 @@ void RenderView::DidDownloadImage(ImageResourceFetcher* fetcher,
MessageLoop::current()->DeleteSoon(FROM_HERE, fetcher);
}
-void RenderView::OnDownloadFavIcon(int id,
+void RenderView::OnDownloadFavicon(int id,
const GURL& image_url,
int image_size) {
bool data_image_failed = false;
@@ -4026,14 +4026,14 @@ void RenderView::OnDownloadFavIcon(int id,
SkBitmap data_image = ImageFromDataUrl(image_url);
data_image_failed = data_image.empty();
if (!data_image_failed) {
- Send(new ViewHostMsg_DidDownloadFavIcon(routing_id_, id, image_url, false,
+ Send(new ViewHostMsg_DidDownloadFavicon(routing_id_, id, image_url, false,
data_image));
}
}
if (data_image_failed ||
!DownloadImage(id, image_url, image_size)) {
- Send(new ViewHostMsg_DidDownloadFavIcon(routing_id_, id, image_url, true,
+ Send(new ViewHostMsg_DidDownloadFavicon(routing_id_, id, image_url, true,
SkBitmap()));
}
}
diff --git a/chrome/renderer/render_view.h b/chrome/renderer/render_view.h
index 705f12e..d1c9395 100644
--- a/chrome/renderer/render_view.h
+++ b/chrome/renderer/render_view.h
@@ -826,7 +826,7 @@ class RenderView : public RenderWidget,
void OnDisableScrollbarsForSmallWindows(
const gfx::Size& disable_scrollbars_size_limit);
void OnDisassociateFromPopupCount();
- void OnDownloadFavIcon(int id, const GURL& image_url, int image_size);
+ void OnDownloadFavicon(int id, const GURL& image_url, int image_size);
void OnDragSourceEndedOrMoved(const gfx::Point& client_point,
const gfx::Point& screen_point,
bool ended,
diff --git a/chrome/common/render_messages.h b/chrome/common/render_messages.h
index b12f474..db74cb8 100644
--- a/chrome/common/render_messages.h
+++ b/chrome/common/render_messages.h
@@ -779,8 +779,8 @@ IPC_MESSAGE_ROUTED3(ViewMsg_GetSerializedHtmlDataForCurrentPageWithLocalLinks,
IPC_MESSAGE_ROUTED1(ViewMsg_GetApplicationInfo, int32 /*page_id*/)
// Requests the renderer to download the specified favicon image encode it as
-// PNG and send the PNG data back ala ViewHostMsg_DidDownloadFavIcon.
-IPC_MESSAGE_ROUTED3(ViewMsg_DownloadFavIcon,
+// PNG and send the PNG data back ala ViewHostMsg_DidDownloadFavicon.
+IPC_MESSAGE_ROUTED3(ViewMsg_DownloadFavicon,
int /* identifier for the request */,
GURL /* URL of the image */,
int /* Size of the image. Normally 0, but set if you have
@@ -1549,7 +1549,7 @@ IPC_MESSAGE_ROUTED1(ViewHostMsg_Snapshot,
SkBitmap /* bitmap */)
// Notification that the url for the favicon of a site has been determined.
-IPC_MESSAGE_ROUTED2(ViewHostMsg_UpdateFavIconURL,
+IPC_MESSAGE_ROUTED2(ViewHostMsg_UpdateFaviconURL,
int32 /* page_id */,
GURL /* url of the favicon */)
@@ -1868,7 +1868,7 @@ IPC_MESSAGE_ROUTED1(ViewHostMsg_ShouldClose_ACK,
IPC_MESSAGE_ROUTED1(ViewHostMsg_ClosePage_ACK,
ViewMsg_ClosePage_Params)
-IPC_MESSAGE_ROUTED4(ViewHostMsg_DidDownloadFavIcon,
+IPC_MESSAGE_ROUTED4(ViewHostMsg_DidDownloadFavicon,
int /* Identifier of the request */,
GURL /* URL of the image */,
bool /* true if there was a network error */,